function [] = demo()
% Generate training and testing data for 2 different classes and classify
% with NonNegative Matrix Completion...

[X_tr,Y_tr,X_tst,Y_tst] = generate_data(true);

Y_groundtruth = Y_tst;
Y_tst = NaN*ones(size(Y_tst));
Y = [Y_tr, Y_tst];
X = [X_tr, X_tst];

% Normalize feature vectors
m = min(min(X));
M = max(max(X));
X = (X - m) / (M - m);

[auroc,D] = MC_NonNeg([Y;X], Y_groundtruth, 1, 0.25, 1e-5, 3, 3, 1);

D(1,D(1,:)>0) = 1;
D(1,D(1,:)<=0) = -1;
t = size((find(D(1,size(X_tr,2)+1:end) == Y_groundtruth)));
fprintf ('Accuracy = %.4f\n', t(1,2)/size(Y_groundtruth,2));
fprintf ('Done.\n');

%% Data Generation
function [X_tr,Y_tr,X_tst,Y_tst] = generate_data(add_noise)
n_tr = 400;
n_tst = 100;
d = 10;
D = 100;

[U,S,V] = svd(rand(D));
U1 = U(:,1:d);
X_tr = U1*rand(d,n_tr);
Y_tr = ones(1,n_tr);
X_tst = U1*rand(d,n_tst);
Y_tst = ones(1,n_tst);

R = orth(rand(D));
U1 = R*U1;
X_tr = [X_tr,U1*rand(d,n_tr)];
Y_tr = [Y_tr,(-1)*ones(1,n_tr)];
X_tst = [X_tst,U1*rand(d,n_tst)];
Y_tst = [Y_tst,(-1)*ones(1,n_tst)];

fprintf ('Generated the data...\n');

% Adding some random noise
if (add_noise)
    nX = size(X_tr,2);
    norm_x = sqrt(sum(X_tr.^2,1));
    norm_x = repmat(norm_x,D,1);
    gn = norm_x.*randn(D,nX);
    inds = rand(1,nX)<=0.3;
    X_tr(:,inds) = X_tr(:,inds) + 0.3*gn(:,inds);

    nX = size(X_tst,2);
    norm_x = sqrt(sum(X_tst.^2,1));
    norm_x = repmat(norm_x,D,1);
    gn = norm_x.*randn(D,nX);
    inds = rand(1,nX)<=0.3;
    X_tst(:,inds) = X_tst(:,inds) + 0.3*gn(:,inds);
end

